@@ -10,6 +10,12 @@ from setuptools_scm.file_finder_git import git_find_files
 import warnings
 
 
+skip_if_win_27 = pytest.mark.skipif(
+    sys.platform == "win32" and sys.version_info[0] < 3,
+    reason="Not supported on Windows + Python 2.7",
+)
+
+
 with warnings.catch_warnings():
     warnings.filterwarnings("ignore")
     if not has_command("git"):
@@ -186,6 +192,7 @@ def test_alphanumeric_tags_match(wd):
     assert wd.version.startswith("0.1.dev1+g")
 
 
+@skip_if_win_27
 def test_git_archive_export_ignore(wd, monkeypatch):
     wd.write("test1.txt", "test")
     wd.write("test2.txt", "test")
@@ -201,6 +208,7 @@ def test_git_archive_export_ignore(wd, monkeypatch):
     assert integration.find_files(".") == [opj(".", "test1.txt")]
 
 
+@skip_if_win_27
 @pytest.mark.issue(228)
 def test_git_archive_subdirectory(wd, monkeypatch):
     wd("mkdir foobar")
@@ -211,6 +219,7 @@ def test_git_archive_subdirectory(wd, monkeypatch):
     assert integration.find_files(".") == [opj(".", "foobar", "test1.txt")]
 
 
+@skip_if_win_27
 @pytest.mark.issue(251)
 def test_git_archive_run_from_subdirectory(wd, monkeypatch):
     wd("mkdir foobar")
